@@ -15,18 +15,22 @@ function(net, directed = NULL, gconly = TRUE, precomp.dist = NULL, alpha=1){
   }
   if(gconly) {
     # Sum up distances to all other nodes to get farness
-    out <- cbind(node = attributes(precomp.dist)$nodes, closeness = rowSums(precomp.dist, na.rm = TRUE))
+    out <- cbind(
+      node = attributes(precomp.dist)$nodes, 
+      closeness = rowSums(precomp.dist, na.rm = TRUE),
+      n.closeness=NaN)
     # Invert to get closeness
     out[, "closeness"] <- 1/out[, "closeness"]
   } else {
     # Invert distances
     precomp.dist <- 1/precomp.dist
     # Sum up distances to all other nodes to get farness
-    out <- cbind(node = attributes(precomp.dist)$nodes, 
+    out <- cbind(
+      node = attributes(precomp.dist)$nodes, 
       closeness = rowSums(precomp.dist, na.rm = TRUE),
       n.closeness=NaN)
-      out[,"n.closeness"] <- out[,"closeness"]/(nrow(out)-1)
   }
+  out[,"n.closeness"] <- out[,"closeness"]/(nrow(out)-1)
   # Return
   return(out)
 }
